from __future__ import annotations

from ..Qt import QtWidgets, QtCore
from .._py.guidelinewidget import Ui_Form
from .draw_inputs import *
from .draw_objects import *


class DrawingsWidget(QtWidgets.QWidget, Ui_Form):

    def __init__(self, parent=None):
        super().__init__(parent=parent)

        self.setupUi(self)

        self.widgets = [LineWidget(self), MultiPointWidget(self), TextWidget(self), RectangleWidget(self), EllipseWidget(self)]
        for w in self.widgets:
            self.stackedWidget.addWidget(w)

        self.graphs = None

    def update_tree(self):
        for gid, windows in self.graphs.items():
            self.graph_combobox.addItem(windows.title, userData=gid)

    def clear(self):
        self.graph_combobox.clear()

    @QtCore.pyqtSlot(int, name='on_mode_comboBox_currentIndexChanged')
    def change_draw_type(self, idx: int):
        self.stackedWidget.setCurrentIndex(idx)

    @QtCore.pyqtSlot(name='on_createButton_clicked')
    def make_drawing(self):
        dic = self.stackedWidget.currentWidget().collect_args()
        if dic is None:
            QtWidgets.QMessageBox.information(self, 'Not working', 'Something is missing to create this object')
            return

        new_obj = [LineObject, MultipointObject, TextObject, RectangleObject, EllipseObject][self.mode_comboBox.currentIndex()](**dic)
        graph_id = self.graph_combobox.currentData()


        child = QtWidgets.QListWidgetItem(str(new_obj))
        child.setData(QtCore.Qt.UserRole, new_obj.id)
        self.listWidget.addItem(child)

        self.graphs[graph_id].addDrawing(new_obj)

